@@ -63,7 +63,8 @@ getPlayerDataTT <- function(profile,opposition="",host="",dir="./data",file="pla
     
     #cat(url)
     # Read the data from ESPN Cricinfo
-    tables=readHTMLTable(url,stringsAsFactors = F)
+    tabs <- GET(url)
+    tables=readHTMLTable(rawToChar(tabs$content),stringsAsFactors = F)
     
     # Choose appropriate columns
     t <- tables$"Innings by innings list"
